module Button exposing (Attribute, button, color, safeForQuickstrom)

import Accessibility.Styled as Html exposing (Html)
import Css
import Html.Styled.Attributes as Attributes exposing (css)
import Html.Styled.Events as Events


type alias Options =
    { color : Css.Color, safeForQuickstrom : Bool }


type Attribute
    = Color Css.Color
    | SafeForQuickstrom Bool


color : Css.Color -> Attribute
color =
    Color


safeForQuickstrom : Bool -> Attribute
safeForQuickstrom =
    SafeForQuickstrom


customize : Attribute -> Options -> Options
customize attr options =
    case attr of
        Color color_ ->
            { options | color = color_ }

        SafeForQuickstrom safety ->
            { options | safeForQuickstrom = safety }


button : List Attribute -> String -> msg -> Html msg
button attrs label msg =
    let
        config =
            List.foldl
                customize
                { color = Css.hex "CCC"
                , safeForQuickstrom = True
                }
                attrs
    in
    Html.button
        [ css
            [ Css.paddingTop (Css.px 6)
            , Css.paddingBottom (Css.px 10)
            , Css.paddingLeft (Css.px 15)
            , Css.paddingRight (Css.px 15)
            , Css.minWidth (Css.px 100)
            , Css.backgroundColor config.color
            , Css.border Css.zero
            , Css.borderRadius (Css.px 4)
            , Css.boxShadow6 Css.inset Css.zero (Css.px -4) Css.zero Css.zero (Css.rgba 0 0 0 0.1)
            , Css.cursor Css.pointer

            -- font
            , Css.fontSize (Css.px 14)
            , Css.fontWeight (Css.int 600)
            , Css.color (Css.hex "FFF")
            ]
        , Events.onClick msg
        , if config.safeForQuickstrom then
            Attributes.class "quickstrom-safe"

          else
            Attributes.class "quickstrom-unsafe"
        ]
        [ Html.text label ]
